.. _lookup_concept:

===============================
Lookup Tables and Interpolation
===============================

.. contents::
   :depth: 2
   :local:
   :backlinks: none

Outline
-------
 - Translating population data into individual level data.
 - Scalars vs full data.
 - Interpolation orders and strategies.
